@@ -21,6 +21,6 @@ dags = [
     DAG((b, d, result)),
 ]
 
-if __name__ == "__main__":
+if __name__ == '__main__':
     app = partial(dag_app, dags=dags)
     app()
