@@ -4,6 +4,7 @@ import pandas as pd
 import streamlit as st
 from typing import Mapping, Iterable
 from meshed.itools import successors
+from lined import iterize
 
 DFLT_VALS = {
     int: 0,
@@ -51,15 +52,14 @@ def double_slider(node, st_kwargs, col):
                 key=f'{node}_max_val',
                 **st_kwargs,
             )
-            st.number_input(
-                'step', min_value=1, value=5, key=f'{node}_step', **st_kwargs
-            )
+            st.number_input('num', min_value=1, value=5, key=f'{node}_num', **st_kwargs)
             st.write(
                 pd.DataFrame(
-                    np.arange(
+                    np.linspace(
                         start=int(st.session_state[f'{node}_min_val']),
-                        stop=int(st.session_state[f'{node}_max_val'] + 1),
-                        step=int(st.session_state[f'{node}_step']),
+                        stop=int(st.session_state[f'{node}_max_val']),
+                        num=int(st.session_state[f'{node}_num']),
+                        endpoint=True,
                     )
                 ).transpose()
             )
@@ -75,22 +75,38 @@ def vector_factory(dag, nodes, funcs, col):
 def update_vec_nodes(dag, nodes, funcs, col):
     with col:
         for node in [node for node in nodes if node not in dag.roots]:
-            kwargs = dict()
+            # kwargs = dict()
+            args = list()
             for arg in list(funcs[node].sig.names):
                 if arg in dag.roots:
-                    kwargs[arg] = np.arange(
+                    vec_input = np.linspace(
                         start=int(st.session_state[f'{arg}_min_val']),
-                        stop=int(st.session_state[f'{arg}_max_val'] + 1),
-                        step=int(st.session_state[f'{arg}_step']),
+                        stop=int(st.session_state[f'{arg}_max_val']),
+                        num=int(st.session_state[f'{arg}_num']),
+                        endpoint=True,
                     )
+                    if arg in funcs[node].sig.annotations:
+                        arg_type = str(funcs[node].sig.annotations[arg])
+                        if arg_type == 'int':
+                            # kwargs[arg] = vec_input.astype(int)
+                            args.append(list(vec_input.astype(int)))
+                        else:
+                            # kwargs[arg] = vec_input
+                            args.append(list(vec_input))
+                    else:
+                        # kwargs[arg] = vec_input
+                        args.append(list(vec_input))
                 else:
-                    kwargs[arg] = st.session_state[arg]
-            if len(set(map(len, kwargs.values()))) == 1:
-                val = funcs[node].func(**kwargs)
+                    # kwargs[arg] = st.session_state[arg]
+                    args.append(st.session_state[arg])
+            # if len(set(map(len, kwargs.values()))) == 1:
+            if len(set(map(len, [arg for arg in args]))) == 1:
+                func = iterize(funcs[node].func)
+                val = list(func(*args))
                 st.session_state[node] = val
                 st.write(f'{node}: ')
                 # st.line_chart(st.session_state[node])
-                st.write(pd.DataFrame(st.session_state[node]).transpose())
+                st.write(pd.DataFrame(st.session_state[node]))
             else:
                 break
 
